Struct below_model::cgroup::CgroupModel
source · [−]pub struct CgroupModel {
pub data: SingleCgroupModel,
pub children: BTreeSet<CgroupModel>,
pub count: u32,
pub recreate_flag: bool,
}Expand description
A model that represents a cgroup subtree. Each instance is a node that uses the “data” field to represent local data. Otherwise mixing hierarchy and data makes it hard to define a Field Id type that queries nested cgroups.
Fields
data: SingleCgroupModelchildren: BTreeSet<CgroupModel>count: u32Total number of cgroups under this subtree, including self
recreate_flag: boolIndicate if such cgroup is created
Implementations
pub fn new(
name: String,
full_path: String,
depth: u32,
sample: &CgroupSample,
last: Option<(&CgroupSample, Duration)>
) -> CgroupModel