Enum below_model::Field
source · [−]pub enum Field {
U32(u32),
U64(u64),
I32(i32),
I64(i64),
F32(f32),
F64(f64),
Str(String),
PidState(PidState),
}Expand description
A wrapper for different field types used in Models. By this way we can query different fields in a single function without using Box.
Variants
U32(u32)
U64(u64)
I32(i32)
I64(i64)
F32(f32)
F64(f64)
Str(String)
PidState(PidState)