Struct below_model::BTreeMapFieldId
source · [−]Expand description
Type that makes BTreeMap Queriable if its value is Queriable. Uses key
to query into a map. Uses subquery_id to query into the selected value.
Fields
key: Option<K>None is only for listing variants and otherwise invalid.
subquery_id: FTrait Implementations
Return iterator for unit variants as well as nested variants.
Return iterator for unit variants only.
impl<K: PartialEq, F: PartialEq + FieldId> PartialEq<BTreeMapFieldId<K, F>> for BTreeMapFieldId<K, F>
impl<K: PartialEq, F: PartialEq + FieldId> PartialEq<BTreeMapFieldId<K, F>> for BTreeMapFieldId<K, F>
This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.